==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/UpdateDomain.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UpdateDomain
 */
@JsonPropertyOrder({ UpdateDomain.JSON_PROPERTY_BRAND_ID })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class UpdateDomain implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BRAND_ID = "brandId";
    private String brandId;

    public UpdateDomain() {
    }

    public UpdateDomain brandId(String brandId) {

        this.brandId = brandId;
        return this;
    }

    /**
     * The &#x60;id&#x60; of the brand used to replace the existing brand.
     *
     * @return brandId
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(example = "bndul904tTZ6kWVhP0g3", required = true, value = "The `id` of the brand used to replace the existing brand.")
    @JsonProperty(JSON_PROPERTY_BRAND_ID)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getBrandId() {
        return brandId;
    }

    @JsonProperty(JSON_PROPERTY_BRAND_ID)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setBrandId(String brandId) {
        this.brandId = brandId;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UpdateDomain updateDomain = (UpdateDomain) o;
        return Objects.equals(this.brandId, updateDomain.brandId);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(brandId);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UpdateDomain {\n");
        sb.append("    brandId: ").append(toIndentedString(brandId)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/UpdateDomain.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UpdateDomain
 */
@JsonPropertyOrder({ UpdateDomain.JSON_PROPERTY_BRAND_ID })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class UpdateDomain implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_BRAND_ID = "brandId";
    private String brandId;

    public UpdateDomain() {
    }

    public UpdateDomain brandId(String brandId) {

        this.brandId = brandId;
        return this;
    }

    /**
     * The &#x60;id&#x60; of the brand used to replace the existing brand.
     *
     * @return brandId
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(example = "bndul904tTZ6kWVhP0g3", required = true, value = "The `id` of the brand used to replace the existing brand.")
    @JsonProperty(JSON_PROPERTY_BRAND_ID)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getBrandId() {
        return brandId;
    }

    @JsonProperty(JSON_PROPERTY_BRAND_ID)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setBrandId(String brandId) {
        this.brandId = brandId;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UpdateDomain updateDomain = (UpdateDomain) o;
        return Objects.equals(this.brandId, updateDomain.brandId);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(brandId);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UpdateDomain {\n");
        sb.append("    brandId: ").append(toIndentedString(brandId)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
